"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CollectionsList = void 0;
const react_1 = __importDefault(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const format_1 = require("./format");
const namespace_card_1 = require("./namespace-card");
const items_grid_1 = require("./items-grid");
const COLLECTION_CARD_WIDTH = compass_components_1.spacing[6] * 4;
const COLLECTION_CARD_HEIGHT = 238;
const COLLECTION_CARD_LIST_HEIGHT = 118;
function collectionPropertyToBadge({ id, options, }) {
    switch (id) {
        case 'collation':
            return {
                id,
                name: id,
                variant: 'darkgray',
                hint: (react_1.default.createElement(react_1.default.Fragment, null, Object.entries(options ?? {}).map(([key, val]) => val && (react_1.default.createElement("div", { key: key },
                    react_1.default.createElement("strong", null,
                        key,
                        ":"),
                    "\u00A0",
                    val))))),
            };
        case 'view':
            return { id, name: id, variant: 'darkgray', icon: 'Visibility' };
        case 'capped':
            return { id, name: id, variant: 'darkgray' };
        case 'timeseries':
            return { id, name: id, variant: 'darkgray', icon: 'TimeSeries' };
        case 'fle2':
            return {
                id,
                name: 'Queryable Encryption',
                variant: 'darkgray',
                icon: 'Key',
            };
        case 'clustered':
            return { id, name: id, variant: 'darkgray' };
        default:
            return { id, name: id };
    }
}
const pageContainerStyles = (0, compass_components_1.css)({
    height: 'auto',
    width: '100%',
    display: 'flex',
    flexDirection: 'column',
});
const CollectionsList = ({ namespace, collections, onCollectionClick, onCreateCollectionClick, onDeleteCollectionClick, onRefreshClick, }) => {
    return (react_1.default.createElement("div", { className: pageContainerStyles },
        react_1.default.createElement(items_grid_1.ItemsGrid, { namespace: namespace, items: collections, itemType: "collection", itemGridWidth: COLLECTION_CARD_WIDTH, itemGridHeight: COLLECTION_CARD_HEIGHT, itemListHeight: COLLECTION_CARD_LIST_HEIGHT, sortBy: [
                { name: 'name', label: 'Collection Name' },
                { name: 'document_count', label: 'Documents' },
                { name: 'avg_document_size', label: 'Avg. document size' },
                { name: 'storage_size', label: 'Storage size' },
                { name: 'index_count', label: 'Indexes' },
                { name: 'index_size', label: 'Total index size' },
            ], onItemClick: onCollectionClick, onDeleteItemClick: onDeleteCollectionClick, onCreateItemClick: onCreateCollectionClick, onRefreshClick: onRefreshClick, renderItem: ({ item: coll, onItemClick, onDeleteItemClick, ...props }) => {
                const data = coll.type === 'view'
                    ? [{ label: 'View on', value: coll.source?.name }]
                    : coll.type === 'timeseries'
                        ? [
                            {
                                label: 'Storage size',
                                value: (0, format_1.compactBytes)(coll.storage_size - coll.free_storage_size),
                                hint: `Uncompressed data size: ${(0, format_1.compactBytes)(coll.document_size)}`,
                            },
                        ]
                        : [
                            {
                                label: 'Storage size',
                                value: (0, format_1.compactBytes)(coll.storage_size - coll.free_storage_size),
                                hint: `Uncompressed data size: ${(0, format_1.compactBytes)(coll.document_size)}`,
                            },
                            {
                                label: 'Documents',
                                value: (0, format_1.compactNumber)(coll.document_count),
                            },
                            {
                                label: 'Avg. document size',
                                value: (0, format_1.compactBytes)(coll.avg_document_size),
                            },
                            {
                                label: 'Indexes',
                                value: (0, format_1.compactNumber)(coll.index_count),
                            },
                            {
                                label: 'Total index size',
                                value: (0, format_1.compactBytes)(coll.index_size),
                            },
                        ];
                const badges = coll.properties.map((prop) => {
                    return collectionPropertyToBadge(prop);
                });
                return (react_1.default.createElement(namespace_card_1.NamespaceItemCard, { id: coll._id, key: coll._id, name: coll.name, type: "collection", status: coll.status, data: data, badges: badges, onItemClick: onItemClick, onItemDeleteClick: onDeleteItemClick, ...props }));
            } })));
};
exports.CollectionsList = CollectionsList;
//# sourceMappingURL=collections.js.map